@@ -144,19 +144,20 @@ class Recipe:
                 ip_address = 'ip-address %s' % ip_address
             
             zope_conf_additional = options.get('zope-conf-additional', '')
-        
+            
             base_dir = self.buildout['buildout']['directory']
-        
-            event_log_name = options.get('event-log', os.path.sep.join(('var', 'log', self.name + '.log',)))
-            event_log = os.path.join(base_dir, event_log_name)
+            var_dir = options.get('var', os.path.join(base_dir, 'var'))
+            
+            event_log_name = options.get('event-log', os.path.sep.join(('log', self.name + '.log',)))
+            event_log = os.path.join(var_dir, event_log_name)
             event_log_dir = os.path.dirname(event_log)
             if not os.path.exists(event_log_dir):
                 os.makedirs(event_log_dir)
             
             event_log_level = options.get('event-log-level', 'INFO')
             
-            z_log_name = options.get('z-log', os.path.sep.join(('var', 'log', self.name + '-Z2.log',)))
-            z_log = os.path.join(base_dir, z_log_name)
+            z_log_name = options.get('z-log', os.path.sep.join(('log', self.name + '-Z2.log',)))
+            z_log = os.path.join(var_dir, z_log_name)
             z_log_dir = os.path.dirname(z_log)
             if not os.path.exists(z_log_dir):
                 os.makedirs(z_log_dir)
@@ -167,8 +168,8 @@ class Recipe:
             if default_zpublisher_encoding:
                 default_zpublisher_encoding = 'default-zpublisher-encoding %s' % default_zpublisher_encoding
             
-            file_storage = options.get('file-storage', os.path.sep.join(('var', 'filestorage', 'Data.fs',)))
-            file_storage = os.path.join(base_dir, file_storage)
+            file_storage = options.get('file-storage', os.path.sep.join(('filestorage', 'Data.fs',)))
+            file_storage = os.path.join(var_dir, file_storage)
             file_storage_dir = os.path.dirname(file_storage)
             if not os.path.exists(file_storage_dir):
                 os.makedirs(file_storage_dir)
@@ -193,16 +194,36 @@ class Recipe:
             zeo_storage = options.get('zeo-storage', '1')
 
             if zeo_client.lower() in ('yes', 'true', 'on', '1'):
-                template = zeo_conf_template
+                zeo_client_name = options.get('zeo-client-name', self.name)
+                zeo_var_dir = options.get('zeo-var',
+                                          os.path.join(instance_home, 'var'))
+                shared_blob_dir = options.get('shared-blob', 'no')
+                if zeo_client_name:
+                    zeo_client_name = 'zeo-client-name %s' % zeo_client_name
+                if blob_storage:
+                    storage_snippet_template = zeo_blob_storage_template
+                else:
+                    storage_snippet_template = zeo_storage_template
+                storage_snippet = storage_snippet_template % dict(
+                    blob_storage = blob_storage,
+                    shared_blob_dir = shared_blob_dir,
+                    zeo_address = zeo_address,
+                    zeo_client_cache_size = zeo_client_cache_size,
+                    zeo_storage = zeo_storage,
+                    zeo_var_dir=zeo_var_dir,
+                    )
             else:
-                template = zope_conf_template
+                # no zeo-client, so no zeo_client_name
+                zeo_client_name = ''
+
+            template = zope_conf_template
 
             pid_file = options.get(
                 'pid-file',
-                os.path.join(base_dir, 'var', self.name + '.pid'))
+                os.path.join(var_dir, self.name + '.pid'))
             lock_file = options.get(
                 'lock-file',
-                os.path.join(base_dir, 'var', self.name + '.lock'))
+                os.path.join(var_dir, self.name + '.lock'))
 
             zope_conf = template % dict(instance_home = instance_home,
                                         products_lines = products_lines,
@@ -219,11 +240,9 @@ class Recipe:
                                         storage_snippet = storage_snippet.strip(),
                                         port_base = port_base,
                                         http_address = http_address,
-                                        zeo_address = zeo_address,
                                         zserver_threads = zserver_threads,
                                         zodb_cache_size = zodb_cache_size,
-                                        zeo_client_cache_size = zeo_client_cache_size,
-                                        zeo_storage = zeo_storage,
+                                        zeo_client_name = zeo_client_name,
                                         pid_file = pid_file,
                                         lock_file = lock_file,
                                         zope_conf_additional = zope_conf_additional,)
@@ -405,11 +424,13 @@ if __name__ == '__main__':
 
 # Storage snippets for zope.conf template
 file_storage_template="""
+    # FileStorage database
     <filestorage>
       path %s
     </filestorage>
 """
 blob_storage_template="""
+    # Blob-enabled FileStorage database
     <blobstorage>
       blob-dir %s
       <filestorage>
@@ -418,6 +439,30 @@ blob_storage_template="""
     </blobstorage>
 """
 
+zeo_storage_template="""
+    # ZEOStorage database
+    <zeoclient>
+      server %(zeo_address)s
+      storage %(zeo_storage)s
+      name zeostorage
+      var %(zeo_var_dir)s
+      cache-size %(zeo_client_cache_size)s
+    </zeoclient>
+""".strip()
+
+zeo_blob_storage_template="""
+    # Blob-enabled ZEOStorage database
+    <zeoclient>
+      blob-dir %(blob_storage)s
+      shared-blob-dir %(shared_blob_dir)s
+      server %(zeo_address)s
+      storage %(zeo_storage)s
+      name zeostorage
+      var %(zeo_var_dir)s
+      cache-size %(zeo_client_cache_size)s
+    </zeoclient>
+""".strip()
+
 # The template used to build zope.conf
 zope_conf_template="""\
 instancehome %(instance_home)s
@@ -430,6 +475,7 @@ verbose-security %(verbose_security)s
 %(effective_user)s
 %(ip_address)s
 %(zserver_threads)s
+%(zeo_client_name)s
 
 <eventlog>
   level %(event_log_level)s
@@ -456,9 +502,9 @@ verbose-security %(verbose_security)s
 </http-server>
 
 <zodb_db main>
-    # Main FileStorage database
+    # Main database
     cache-size %(zodb_cache_size)s
-    %(storage_snippet)s
+%(storage_snippet)s
     mount-point /
 </zodb_db>
 
@@ -476,66 +522,3 @@ lock-filename %(lock_file)s
 
 %(zope_conf_additional)s
 """
-
-zeo_conf_template="""\
-instancehome %(instance_home)s
-%(products_lines)s
-debug-mode %(debug_mode)s
-security-policy-implementation %(security_implementation)s
-verbose-security %(verbose_security)s
-%(default_zpublisher_encoding)s
-%(port_base)s
-%(effective_user)s
-%(ip_address)s
-%(zserver_threads)s
-
-<eventlog>
-  level %(event_log_level)s
-  <logfile>
-    path %(event_log)s
-    level info
-  </logfile>
-</eventlog>
-
-<logger access>
-  level %(z_log_level)s
-  <logfile>
-    path %(z_log)s
-    format %%(message)s
-  </logfile>
-</logger>
-
-<http-server>
-  # valid keys are "address" and "force-connection-close"
-  address %(http_address)s
-  # force-connection-close on
-  # You can also use the WSGI interface between ZServer and ZPublisher:
-  # use-wsgi on
-</http-server>
-
-<zodb_db main>
-  mount-point /
-  cache-size %(zodb_cache_size)s
-  <zeoclient>
-    server %(zeo_address)s
-    storage %(zeo_storage)s
-    name zeostorage
-    var %(instance_home)s/var
-    cache-size %(zeo_client_cache_size)s
-  </zeoclient>
-</zodb_db>
-
-<zodb_db temporary>
-    # Temporary storage database (for sessions)
-    <temporarystorage>
-      name temporary storage for sessioning
-    </temporarystorage>
-    mount-point /temp_folder
-    container-class Products.TemporaryFolder.TemporaryContainer
-</zodb_db>
-
-pid-filename %(pid_file)s
-lock-filename %(lock_file)s
-
-%(zope_conf_additional)s
-"""
